# Toddy for Python

Native GUI toolkit for Python, powered by native rendering via iced.

This is a placeholder release to reserve the package name. The first
functional release is coming soon.

Source: <https://github.com/toddy-ui/toddy>
